@@ -70,8 +70,8 @@ class Limiter:
       by.
     :param app: :class:`flask.Flask` instance to initialize the extension with.
     :param default_limits: a variable list of strings or callables
-     returning strings denoting default limits to apply to all routes.
-     :ref:`ratelimit-string` for  more details.
+     returning strings denoting default limits to apply to all routes that are
+     not explicitely decorated with a limit. :ref:`ratelimit-string` for  more details.
     :param default_limits_per_method: whether default limits are applied
      per method, per route or as a combination of all method per route.
     :param default_limits_exempt_when: a function that should return
@@ -809,7 +809,7 @@ class Limiter:
                 except Exception as err:
                     if self._swallow_errors:
                         self.logger.exception(
-                            "Failed to deduct rate limit. " "Swallowing error"
+                            "Failed to deduct rate limit. Swallowing error"
                         )
                     else:
                         raise err
@@ -832,9 +832,12 @@ class Limiter:
                     str(header_limit.limit.amount),
                 )
                 response.headers.add(
-                    self._header_mapping[HeaderNames.REMAINING], header_limit.remaining
+                    self._header_mapping[HeaderNames.REMAINING],
+                    str(header_limit.remaining),
+                )
+                response.headers.add(
+                    self._header_mapping[HeaderNames.RESET], str(reset_at)
                 )
-                response.headers.add(self._header_mapping[HeaderNames.RESET], reset_at)
 
                 # response may have an existing retry after
                 existing_retry_after_header = response.headers.get("Retry-After")
@@ -858,9 +861,11 @@ class Limiter:
                 # set the header instead of using add
                 response.headers.set(
                     self._header_mapping[HeaderNames.RETRY_AFTER],
-                    self._retry_after == "http-date"
-                    and http_date(reset_at)
-                    or int(reset_at - time.time()),
+                    str(
+                        http_date(reset_at)
+                        if self._retry_after == "http-date"
+                        else int(reset_at - time.time())
+                    ),
                 )
             except Exception as e:  # noqa: E722
                 if self._in_memory_fallback_enabled and not self._storage_dead:
